@@ -1,25 +1,22 @@
 # Natural Language Toolkit: Chunk format conversions
 #
-# Copyright (C) 2001-2019 NLTK Project
+# Copyright (C) 2001-2023 NLTK Project
 # Author: Edward Loper <edloper@gmail.com>
 #         Steven Bird <stevenbird1@gmail.com> (minor additions)
-# URL: <http://nltk.org/>
+# URL: <https://www.nltk.org/>
 # For license information, see LICENSE.TXT
-from __future__ import print_function, unicode_literals, division
 
 import re
 
-from nltk.tree import Tree
+from nltk.metrics import accuracy as _accuracy
 from nltk.tag.mapping import map_tag
 from nltk.tag.util import str2tuple
-from nltk.compat import python_2_unicode_compatible
+from nltk.tree import Tree
 
 ##//////////////////////////////////////////////////////
 ## EVALUATION
 ##//////////////////////////////////////////////////////
 
-from nltk.metrics import accuracy as _accuracy
-
 
 def accuracy(chunker, gold):
     """
@@ -51,7 +48,7 @@ def accuracy(chunker, gold):
 #
 # SB: use nltk.metrics for precision/recall scoring?
 #
-class ChunkScore(object):
+class ChunkScore:
     """
     A utility class for scoring chunk parsers.  ``ChunkScore`` can
     evaluate a chunk parser's output, based on a number of statistics
@@ -120,10 +117,10 @@ class ChunkScore(object):
         self._tp = set()
         self._fp = set()
         self._fn = set()
-        self._max_tp = kwargs.get('max_tp_examples', 100)
-        self._max_fp = kwargs.get('max_fp_examples', 100)
-        self._max_fn = kwargs.get('max_fn_examples', 100)
-        self._chunk_label = kwargs.get('chunk_label', '.*')
+        self._max_tp = kwargs.get("max_tp_examples", 100)
+        self._max_fp = kwargs.get("max_fp_examples", 100)
+        self._max_fn = kwargs.get("max_fn_examples", 100)
+        self._chunk_label = kwargs.get("chunk_label", ".*")
         self._tp_num = 0
         self._fp_num = 0
         self._fn_num = 0
@@ -284,7 +281,7 @@ class ChunkScore(object):
 
         :rtype: str
         """
-        return '<ChunkScoring of ' + repr(len(self)) + ' chunks>'
+        return "<ChunkScoring of " + repr(len(self)) + " chunks>"
 
     def __str__(self):
         """
@@ -297,10 +294,10 @@ class ChunkScore(object):
         """
         return (
             "ChunkParse score:\n"
-            + ("    IOB Accuracy: {:5.1f}%%\n".format(self.accuracy() * 100))
-            + ("    Precision:    {:5.1f}%%\n".format(self.precision() * 100))
-            + ("    Recall:       {:5.1f}%%\n".format(self.recall() * 100))
-            + ("    F-Measure:    {:5.1f}%%".format(self.f_measure() * 100))
+            + (f"    IOB Accuracy: {self.accuracy() * 100:5.1f}%%\n")
+            + (f"    Precision:    {self.precision() * 100:5.1f}%%\n")
+            + (f"    Recall:       {self.recall() * 100:5.1f}%%\n")
+            + (f"    F-Measure:    {self.f_measure() * 100:5.1f}%%")
         )
 
 
@@ -320,7 +317,7 @@ def _chunksets(t, count, chunk_label):
 
 
 def tagstr2tree(
-    s, chunk_label="NP", root_label="S", sep='/', source_tagset=None, target_tagset=None
+    s, chunk_label="NP", root_label="S", sep="/", source_tagset=None, target_tagset=None
 ):
     """
     Divide a string of bracketted tagged text into
@@ -339,20 +336,20 @@ def tagstr2tree(
     :rtype: Tree
     """
 
-    WORD_OR_BRACKET = re.compile(r'\[|\]|[^\[\]\s]+')
+    WORD_OR_BRACKET = re.compile(r"\[|\]|[^\[\]\s]+")
 
     stack = [Tree(root_label, [])]
     for match in WORD_OR_BRACKET.finditer(s):
         text = match.group()
-        if text[0] == '[':
+        if text[0] == "[":
             if len(stack) != 1:
-                raise ValueError('Unexpected [ at char {:d}'.format(match.start()))
+                raise ValueError(f"Unexpected [ at char {match.start():d}")
             chunk = Tree(chunk_label, [])
             stack[-1].append(chunk)
             stack.append(chunk)
-        elif text[0] == ']':
+        elif text[0] == "]":
             if len(stack) != 2:
-                raise ValueError('Unexpected ] at char {:d}'.format(match.start()))
+                raise ValueError(f"Unexpected ] at char {match.start():d}")
             stack.pop()
         else:
             if sep is None:
@@ -364,16 +361,16 @@ def tagstr2tree(
                 stack[-1].append((word, tag))
 
     if len(stack) != 1:
-        raise ValueError('Expected ] at char {:d}'.format(len(s)))
+        raise ValueError(f"Expected ] at char {len(s):d}")
     return stack[0]
 
 
 ### CONLL
 
-_LINE_RE = re.compile('(\S+)\s+(\S+)\s+([IOB])-?(\S+)?')
+_LINE_RE = re.compile(r"(\S+)\s+(\S+)\s+([IOB])-?(\S+)?")
 
 
-def conllstr2tree(s, chunk_types=('NP', 'PP', 'VP'), root_label="S"):
+def conllstr2tree(s, chunk_types=("NP", "PP", "VP"), root_label="S"):
     """
     Return a chunk structure for a single sentence
     encoded in the given CONLL 2000 style string.
@@ -393,29 +390,29 @@ def conllstr2tree(s, chunk_types=('NP', 'PP', 'VP'), root_label="S"):
 
     stack = [Tree(root_label, [])]
 
-    for lineno, line in enumerate(s.split('\n')):
+    for lineno, line in enumerate(s.split("\n")):
         if not line.strip():
             continue
 
         # Decode the line.
         match = _LINE_RE.match(line)
         if match is None:
-            raise ValueError('Error on line {:d}'.format(lineno))
+            raise ValueError(f"Error on line {lineno:d}")
         (word, tag, state, chunk_type) = match.groups()
 
         # If it's a chunk type we don't care about, treat it as O.
         if chunk_types is not None and chunk_type not in chunk_types:
-            state = 'O'
+            state = "O"
 
         # For "Begin"/"Outside", finish any completed chunks -
         # also do so for "Inside" which don't match the previous token.
-        mismatch_I = state == 'I' and chunk_type != stack[-1].label()
-        if state in 'BO' or mismatch_I:
+        mismatch_I = state == "I" and chunk_type != stack[-1].label()
+        if state in "BO" or mismatch_I:
             if len(stack) == 2:
                 stack.pop()
 
         # For "Begin", start a new chunk.
-        if state == 'B' or mismatch_I:
+        if state == "B" or mismatch_I:
             chunk = Tree(chunk_type, [])
             stack[-1].append(chunk)
             stack.append(chunk)
@@ -454,7 +451,7 @@ def tree2conlltags(t):
 
 
 def conlltags2tree(
-    sentence, chunk_types=('NP', 'PP', 'VP'), root_label='S', strict=False
+    sentence, chunk_types=("NP", "PP", "VP"), root_label="S", strict=False
 ):
     """
     Convert the CoNLL IOB format to a tree.
@@ -467,9 +464,9 @@ def conlltags2tree(
             else:
                 # Treat as O
                 tree.append((word, postag))
-        elif chunktag.startswith('B-'):
+        elif chunktag.startswith("B-"):
             tree.append(Tree(chunktag[2:], [(word, postag)]))
-        elif chunktag.startswith('I-'):
+        elif chunktag.startswith("I-"):
             if (
                 len(tree) == 0
                 or not isinstance(tree[-1], Tree)
@@ -482,10 +479,10 @@ def conlltags2tree(
                     tree.append(Tree(chunktag[2:], [(word, postag)]))
             else:
                 tree[-1].append((word, postag))
-        elif chunktag == 'O':
+        elif chunktag == "O":
             tree.append((word, postag))
         else:
-            raise ValueError("Bad conll tag {0!r}".format(chunktag))
+            raise ValueError(f"Bad conll tag {chunktag!r}")
     return tree
 
 
@@ -499,24 +496,24 @@ def tree2conllstr(t):
     :rtype: str
     """
     lines = [" ".join(token) for token in tree2conlltags(t)]
-    return '\n'.join(lines)
+    return "\n".join(lines)
 
 
 ### IEER
 
 _IEER_DOC_RE = re.compile(
-    r'<DOC>\s*'
-    r'(<DOCNO>\s*(?P<docno>.+?)\s*</DOCNO>\s*)?'
-    r'(<DOCTYPE>\s*(?P<doctype>.+?)\s*</DOCTYPE>\s*)?'
-    r'(<DATE_TIME>\s*(?P<date_time>.+?)\s*</DATE_TIME>\s*)?'
-    r'<BODY>\s*'
-    r'(<HEADLINE>\s*(?P<headline>.+?)\s*</HEADLINE>\s*)?'
-    r'<TEXT>(?P<text>.*?)</TEXT>\s*'
-    r'</BODY>\s*</DOC>\s*',
+    r"<DOC>\s*"
+    r"(<DOCNO>\s*(?P<docno>.+?)\s*</DOCNO>\s*)?"
+    r"(<DOCTYPE>\s*(?P<doctype>.+?)\s*</DOCTYPE>\s*)?"
+    r"(<DATE_TIME>\s*(?P<date_time>.+?)\s*</DATE_TIME>\s*)?"
+    r"<BODY>\s*"
+    r"(<HEADLINE>\s*(?P<headline>.+?)\s*</HEADLINE>\s*)?"
+    r"<TEXT>(?P<text>.*?)</TEXT>\s*"
+    r"</BODY>\s*</DOC>\s*",
     re.DOTALL,
 )
 
-_IEER_TYPE_RE = re.compile('<b_\w+\s+[^>]*?type="(?P<type>\w+)"')
+_IEER_TYPE_RE = re.compile(r'<b_\w+\s+[^>]*?type="(?P<type>\w+)"')
 
 
 def _ieer_read_text(s, root_label):
@@ -525,44 +522,44 @@ def _ieer_read_text(s, root_label):
     # return the empty list in place of a Tree
     if s is None:
         return []
-    for piece_m in re.finditer('<[^>]+>|[^\s<]+', s):
+    for piece_m in re.finditer(r"<[^>]+>|[^\s<]+", s):
         piece = piece_m.group()
         try:
-            if piece.startswith('<b_'):
+            if piece.startswith("<b_"):
                 m = _IEER_TYPE_RE.match(piece)
                 if m is None:
-                    print('XXXX', piece)
-                chunk = Tree(m.group('type'), [])
+                    print("XXXX", piece)
+                chunk = Tree(m.group("type"), [])
                 stack[-1].append(chunk)
                 stack.append(chunk)
-            elif piece.startswith('<e_'):
+            elif piece.startswith("<e_"):
                 stack.pop()
             #           elif piece.startswith('<'):
             #               print "ERROR:", piece
             #               raise ValueError # Unexpected HTML
             else:
                 stack[-1].append(piece)
-        except (IndexError, ValueError):
+        except (IndexError, ValueError) as e:
             raise ValueError(
-                'Bad IEER string (error at character {:d})'.format(piece_m.start())
-            )
+                f"Bad IEER string (error at character {piece_m.start():d})"
+            ) from e
     if len(stack) != 1:
-        raise ValueError('Bad IEER string')
+        raise ValueError("Bad IEER string")
     return stack[0]
 
 
 def ieerstr2tree(
     s,
     chunk_types=[
-        'LOCATION',
-        'ORGANIZATION',
-        'PERSON',
-        'DURATION',
-        'DATE',
-        'CARDINAL',
-        'PERCENT',
-        'MONEY',
-        'MEASURE',
+        "LOCATION",
+        "ORGANIZATION",
+        "PERSON",
+        "DURATION",
+        "DATE",
+        "CARDINAL",
+        "PERCENT",
+        "MONEY",
+        "MEASURE",
     ],
     root_label="S",
 ):
@@ -582,13 +579,13 @@ def ieerstr2tree(
     m = _IEER_DOC_RE.match(s)
     if m:
         return {
-            'text': _ieer_read_text(m.group('text'), root_label),
-            'docno': m.group('docno'),
-            'doctype': m.group('doctype'),
-            'date_time': m.group('date_time'),
+            "text": _ieer_read_text(m.group("text"), root_label),
+            "docno": m.group("docno"),
+            "doctype": m.group("doctype"),
+            "date_time": m.group("date_time"),
             #'headline': m.group('headline')
             # we want to capture NEs in the headline too!
-            'headline': _ieer_read_text(m.group('headline'), root_label),
+            "headline": _ieer_read_text(m.group("headline"), root_label),
         }
     else:
         return _ieer_read_text(s, root_label)
@@ -599,7 +596,7 @@ def demo():
     s = "[ Pierre/NNP Vinken/NNP ] ,/, [ 61/CD years/NNS ] old/JJ ,/, will/MD join/VB [ the/DT board/NN ] ./."
     import nltk
 
-    t = nltk.chunk.tagstr2tree(s, chunk_label='NP')
+    t = nltk.chunk.tagstr2tree(s, chunk_label="NP")
     t.pprint()
     print()
 
@@ -633,7 +630,7 @@ better JJR I-ADJP
 . . O
 """
 
-    conll_tree = conllstr2tree(s, chunk_types=('NP', 'PP'))
+    conll_tree = conllstr2tree(s, chunk_types=("NP", "PP"))
     conll_tree.pprint()
 
     # Demonstrate CoNLL output
@@ -642,5 +639,5 @@ better JJR I-ADJP
     print()
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     demo()
