@@ -5,7 +5,7 @@ import os
 import re
 from functools import reduce
 
-from nltk.corpus.reader import concat, TaggedCorpusReader
+from nltk.corpus.reader import TaggedCorpusReader, concat
 from nltk.corpus.reader.xmldocs import XMLCorpusView
 
 
@@ -38,11 +38,11 @@ class MTEFileReader:
     """
 
     ns = {
-        "tei": "http://www.tei-c.org/ns/1.0",
-        "xml": "http://www.w3.org/XML/1998/namespace",
+        "tei": "https://www.tei-c.org/ns/1.0",
+        "xml": "https://www.w3.org/XML/1998/namespace",
     }
-    tag_ns = "{http://www.tei-c.org/ns/1.0}"
-    xml_ns = "{http://www.w3.org/XML/1998/namespace}"
+    tag_ns = "{https://www.tei-c.org/ns/1.0}"
+    xml_ns = "{https://www.w3.org/XML/1998/namespace}"
     word_path = "TEI/text/body/div/div/p/s/(w|c)"
     sent_path = "TEI/text/body/div/div/p/s"
     para_path = "TEI/text/body/div/div/p"
@@ -223,9 +223,10 @@ class MTECorpusReader(TaggedCorpusReader):
 
         :param root: The root directory for this corpus. (default points to location in multext config file)
         :param fileids: A list or regexp specifying the fileids in this corpus. (default is oana-en.xml)
-        :param enconding: The encoding of the given files (default is utf8)
+        :param encoding: The encoding of the given files (default is utf8)
         """
         TaggedCorpusReader.__init__(self, root, fileids, encoding)
+        self._readme = "00README.txt"
 
     def __fileids(self, fileids):
         if fileids is None:
@@ -240,25 +241,9 @@ class MTECorpusReader(TaggedCorpusReader):
             print("No valid multext-east file specified")
         return fileids
 
-    def readme(self):
-        """
-        Prints some information about this corpus.
-        :return: the content of the attached README file
-        :rtype: str
-        """
-        return self.open("00README.txt").read()
-
-    def raw(self, fileids=None):
-        """
-	    :param fileids: A list specifying the fileids that should be used.
-        :return: the given file(s) as a single string.
-        :rtype: str
-        """
-        return reduce([self.open(f).read() for f in self.__fileids(fileids)], [])
-
     def words(self, fileids=None):
         """
-	    :param fileids: A list specifying the fileids that should be used.
+        :param fileids: A list specifying the fileids that should be used.
         :return: the given file(s) as a list of words and punctuation symbols.
         :rtype: list(str)
         """
@@ -271,7 +256,7 @@ class MTECorpusReader(TaggedCorpusReader):
 
     def sents(self, fileids=None):
         """
-	    :param fileids: A list specifying the fileids that should be used.
+        :param fileids: A list specifying the fileids that should be used.
         :return: the given file(s) as a list of sentences or utterances,
                  each encoded as a list of word strings
         :rtype: list(list(str))
@@ -285,7 +270,7 @@ class MTECorpusReader(TaggedCorpusReader):
 
     def paras(self, fileids=None):
         """
-	    :param fileids: A list specifying the fileids that should be used.
+        :param fileids: A list specifying the fileids that should be used.
         :return: the given file(s) as a list of paragraphs, each encoded as a list
                  of sentences, which are in turn encoded as lists of word string
         :rtype: list(list(list(str)))
@@ -299,7 +284,7 @@ class MTECorpusReader(TaggedCorpusReader):
 
     def lemma_words(self, fileids=None):
         """
-	    :param fileids: A list specifying the fileids that should be used.
+        :param fileids: A list specifying the fileids that should be used.
         :return: the given file(s) as a list of words, the corresponding lemmas
                  and punctuation symbols, encoded as tuples (word, lemma)
         :rtype: list(tuple(str,str))
@@ -313,7 +298,7 @@ class MTECorpusReader(TaggedCorpusReader):
 
     def tagged_words(self, fileids=None, tagset="msd", tags=""):
         """
-	    :param fileids: A list specifying the fileids that should be used.
+        :param fileids: A list specifying the fileids that should be used.
         :param tagset: The tagset that should be used in the returned object,
                        either "universal" or "msd", "msd" is the default
         :param tags: An MSD Tag that is used to filter all parts of the used corpus
@@ -336,7 +321,7 @@ class MTECorpusReader(TaggedCorpusReader):
 
     def lemma_sents(self, fileids=None):
         """
-	    :param fileids: A list specifying the fileids that should be used.
+        :param fileids: A list specifying the fileids that should be used.
         :return: the given file(s) as a list of sentences or utterances, each
                  encoded as a list of tuples of the word and the corresponding
                  lemma (word, lemma)
@@ -351,7 +336,7 @@ class MTECorpusReader(TaggedCorpusReader):
 
     def tagged_sents(self, fileids=None, tagset="msd", tags=""):
         """
-	    :param fileids: A list specifying the fileids that should be used.
+        :param fileids: A list specifying the fileids that should be used.
         :param tagset: The tagset that should be used in the returned object,
                        either "universal" or "msd", "msd" is the default
         :param tags: An MSD Tag that is used to filter all parts of the used corpus
@@ -374,7 +359,7 @@ class MTECorpusReader(TaggedCorpusReader):
 
     def lemma_paras(self, fileids=None):
         """
-	    :param fileids: A list specifying the fileids that should be used.
+        :param fileids: A list specifying the fileids that should be used.
         :return: the given file(s) as a list of paragraphs, each encoded as a
                  list of sentences, which are in turn encoded as a list of
                  tuples of the word and the corresponding lemma (word, lemma)
@@ -389,7 +374,7 @@ class MTECorpusReader(TaggedCorpusReader):
 
     def tagged_paras(self, fileids=None, tagset="msd", tags=""):
         """
-	    :param fileids: A list specifying the fileids that should be used.
+        :param fileids: A list specifying the fileids that should be used.
         :param tagset: The tagset that should be used in the returned object,
                        either "universal" or "msd", "msd" is the default
         :param tags: An MSD Tag that is used to filter all parts of the used corpus
