@@ -1,9 +1,9 @@
 # Natural Language Toolkit: Parser API
 #
-# Copyright (C) 2001-2015 NLTK Project
+# Copyright (C) 2001-2023 NLTK Project
 # Author: Steven Bird <stevenbird1@gmail.com>
 #         Edward Loper <edloper@gmail.com>
-# URL: <http://nltk.org/>
+# URL: <https://www.nltk.org/>
 # For license information, see LICENSE.TXT
 #
 
@@ -11,7 +11,8 @@ import itertools
 
 from nltk.internals import overridden
 
-class ParserI(object):
+
+class ParserI:
     """
     A processing class for deriving trees that represent possible
     structures for a sequence of tokens.  These tree structures are
@@ -26,6 +27,7 @@ class ParserI(object):
     Subclasses may define:
       - ``grammar()``
     """
+
     def grammar(self):
         """
         :return: The grammar used by this parser.
@@ -35,7 +37,7 @@ class ParserI(object):
     def parse(self, sent, *args, **kwargs):
         """
         :return: An iterator that generates parse trees for the sentence.
-        When possible this list is sorted from most likely to least likely.
+            When possible this list is sorted from most likely to least likely.
 
         :param sent: The sentence to be parsed
         :type sent: list(str)
@@ -44,7 +46,11 @@ class ParserI(object):
         if overridden(self.parse_sents):
             return next(self.parse_sents([sent], *args, **kwargs))
         elif overridden(self.parse_one):
-            return (tree for tree in [self.parse_one(sent, *args, **kwargs)] if tree is not None)
+            return (
+                tree
+                for tree in [self.parse_one(sent, *args, **kwargs)]
+                if tree is not None
+            )
         elif overridden(self.parse_all):
             return iter(self.parse_all(sent, *args, **kwargs))
         else:
