@@ -1,12 +1,11 @@
-# -*- coding: utf-8 -*-
 # Natural Language Toolkit: A Chart Parser
 #
-# Copyright (C) 2001-2020 NLTK Project
+# Copyright (C) 2001-2023 NLTK Project
 # Author: Edward Loper <edloper@gmail.com>
 #         Steven Bird <stevenbird1@gmail.com>
 #         Jean Mark Gawron <gawron@mail.sdsu.edu>
 #         Peter Ljunglöf <peter.ljunglof@heatherleaf.se>
-# URL: <http://nltk.org/>
+# URL: <https://www.nltk.org/>
 # For license information, see LICENSE.TXT
 
 """
@@ -41,13 +40,11 @@ import re
 import warnings
 from functools import total_ordering
 
-from nltk.tree import Tree
 from nltk.grammar import PCFG, is_nonterminal, is_terminal
-from nltk.util import OrderedDict
 from nltk.internals import raise_unorderable_types
-
 from nltk.parse.api import ParserI
-
+from nltk.tree import Tree
+from nltk.util import OrderedDict
 
 ########################################################################
 ##  Edges
@@ -55,7 +52,7 @@ from nltk.parse.api import ParserI
 
 
 @total_ordering
-class EdgeI(object):
+class EdgeI:
     """
     A hypothesis about the structure of part of a sentence.
     Each edge records the fact that a structure is (partially)
@@ -345,7 +342,7 @@ class TreeEdge(EdgeI):
 
     # String representation
     def __str__(self):
-        str = "[%s:%s] " % (self._span[0], self._span[1])
+        str = f"[{self._span[0]}:{self._span[1]}] "
         str += "%-2r ->" % (self._lhs,)
 
         for i in range(len(self._rhs)):
@@ -419,7 +416,7 @@ class LeafEdge(EdgeI):
 
     # String representations
     def __str__(self):
-        return "[%s:%s] %s" % (self._index, self._index + 1, repr(self._leaf))
+        return f"[{self._index}:{self._index + 1}] {repr(self._leaf)}"
 
     def __repr__(self):
         return "[Edge: %s]" % (self)
@@ -430,7 +427,7 @@ class LeafEdge(EdgeI):
 ########################################################################
 
 
-class Chart(object):
+class Chart:
     """
     A blackboard for hypotheses about the syntactic constituents of a
     sentence.  A chart contains a set of edges, and each edge encodes
@@ -677,8 +674,7 @@ class Chart(object):
         the entire chart, and whose root node is ``root``.
         """
         for edge in self.select(start=0, end=self._num_leaves, lhs=root):
-            for tree in self.trees(edge, tree_class=tree_class, complete=True):
-                yield tree
+            yield from self.trees(edge, tree_class=tree_class, complete=True)
 
     def trees(self, edge, tree_class=Tree, complete=False):
         """
@@ -830,7 +826,7 @@ class Chart(object):
             width = 50 // (self.num_leaves() + 1)
         # sort edges: primary key=length, secondary key=start index.
         # (and filter out the token edges)
-        edges = sorted([(e.length(), e.start(), e) for e in self])
+        edges = sorted((e.length(), e.start(), e) for e in self)
         edges = [e for (_, _, e) in edges]
 
         return (
@@ -915,7 +911,7 @@ class Chart(object):
 ########################################################################
 
 
-class ChartRuleI(object):
+class ChartRuleI:
     """
     A rule that specifies what new edges are licensed by any given set
     of existing edges.  Each chart rule expects a fixed number of
@@ -969,7 +965,7 @@ class AbstractChartRule(ChartRuleI):
 
     - A default implementation for ``apply``.
     - A default implementation for ``apply_everywhere``,
-      (Currently, this implementation assumes that ``NUM_EDGES``<=3.)
+      (Currently, this implementation assumes that ``NUM_EDGES <= 3``.)
     - A default implementation for ``__str__``, which returns a
       name based on the rule's class name.
     """
@@ -982,26 +978,22 @@ class AbstractChartRule(ChartRuleI):
     # self.apply() for each set of edges.
     def apply_everywhere(self, chart, grammar):
         if self.NUM_EDGES == 0:
-            for new_edge in self.apply(chart, grammar):
-                yield new_edge
+            yield from self.apply(chart, grammar)
 
         elif self.NUM_EDGES == 1:
             for e1 in chart:
-                for new_edge in self.apply(chart, grammar, e1):
-                    yield new_edge
+                yield from self.apply(chart, grammar, e1)
 
         elif self.NUM_EDGES == 2:
             for e1 in chart:
                 for e2 in chart:
-                    for new_edge in self.apply(chart, grammar, e1, e2):
-                        yield new_edge
+                    yield from self.apply(chart, grammar, e1, e2)
 
         elif self.NUM_EDGES == 3:
             for e1 in chart:
                 for e2 in chart:
                     for e3 in chart:
-                        for new_edge in self.apply(chart, grammar, e1, e2, e3):
-                            yield new_edge
+                        yield from self.apply(chart, grammar, e1, e2, e3)
 
         else:
             raise AssertionError("NUM_EDGES>3 is not currently supported")
@@ -1018,7 +1010,7 @@ class AbstractChartRule(ChartRuleI):
 
 
 class FundamentalRule(AbstractChartRule):
-    """
+    r"""
     A rule that joins two adjacent edges to form a single combined
     edge.  In particular, this rule specifies that any pair of edges
 
@@ -1051,7 +1043,7 @@ class FundamentalRule(AbstractChartRule):
 
 
 class SingleEdgeFundamentalRule(FundamentalRule):
-    """
+    r"""
     A rule that joins a given edge with adjacent edges in the chart,
     to form combined edges.  In particular, this rule specifies that
     either of the edges:
@@ -1073,11 +1065,9 @@ class SingleEdgeFundamentalRule(FundamentalRule):
 
     def apply(self, chart, grammar, edge):
         if edge.is_incomplete():
-            for new_edge in self._apply_incomplete(chart, grammar, edge):
-                yield new_edge
+            yield from self._apply_incomplete(chart, grammar, edge)
         else:
-            for new_edge in self._apply_complete(chart, grammar, edge):
-                yield new_edge
+            yield from self._apply_complete(chart, grammar, edge)
 
     def _apply_complete(self, chart, grammar, right_edge):
         for left_edge in chart.select(
@@ -1117,7 +1107,7 @@ class LeafInitRule(AbstractChartRule):
 
 
 class TopDownInitRule(AbstractChartRule):
-    """
+    r"""
     A rule licensing edges corresponding to the grammar productions for
     the grammar's start symbol.  In particular, this rule specifies that
     ``[S -> \* alpha][0:i]`` is licensed for each grammar production
@@ -1134,7 +1124,7 @@ class TopDownInitRule(AbstractChartRule):
 
 
 class TopDownPredictRule(AbstractChartRule):
-    """
+    r"""
     A rule licensing edges corresponding to the grammar productions
     for the nonterminal following an incomplete edge's dot.  In
     particular, this rule specifies that
@@ -1156,7 +1146,7 @@ class TopDownPredictRule(AbstractChartRule):
 
 
 class CachedTopDownPredictRule(TopDownPredictRule):
-    """
+    r"""
     A cached version of ``TopDownPredictRule``.  After the first time
     this rule is applied to an edge with a given ``end`` and ``next``,
     it will not generate any more edges for edges with that ``end`` and
@@ -1207,7 +1197,7 @@ class CachedTopDownPredictRule(TopDownPredictRule):
 
 
 class BottomUpPredictRule(AbstractChartRule):
-    """
+    r"""
     A rule licensing any edge corresponding to a production whose
     right-hand side begins with a complete edge's left-hand side.  In
     particular, this rule specifies that ``[A -> alpha \*]`` licenses
@@ -1226,7 +1216,7 @@ class BottomUpPredictRule(AbstractChartRule):
 
 
 class BottomUpPredictCombineRule(BottomUpPredictRule):
-    """
+    r"""
     A rule licensing any edge corresponding to a production whose
     right-hand side begins with a complete edge's left-hand side.  In
     particular, this rule specifies that ``[A -> alpha \*]``
@@ -1742,8 +1732,10 @@ def demo(
     """
     A demonstration of the chart parsers.
     """
-    import sys, time
-    from nltk import nonterminals, Production, CFG
+    import sys
+    import time
+
+    from nltk import CFG, Production, nonterminals
 
     # The grammar for ChartParser and SteppingChartParser:
     grammar = demo_grammar()
